const path = require('path');
const execSync = require('child_process').execSync;
const fs = require('fs-extra');
const download = require('download-git-repo');
const ora = require('ora');
const spawn = require('cross-spawn');
const commander = require('commander');
const inquirer = require('inquirer');
const rm = require('rimraf').sync;
const exists = require('fs').existsSync;
const packageJson = require('../package.json');

const templatesPath = '../templates/';

function createApp (name) {
    //检查输入项目名是否合法
    checkName(name);
    selectTemplate(name);
}

function start(name, type, gitUrl) {
    let sourceDir;

    fs.ensureDirSync(name);

    if (gitUrl) {
        cloneAndGenerate(name, gitUrl);
        return;
    }

    switch (type) {
        case 'react项目': {
            sourceDir = path.resolve(__dirname, templatesPath + 'react');
            break;
        }
        case 'vue项目': {
            sourceDir = path.resolve(__dirname, templatesPath + 'vue');
            break;
        }
        case '快站平台react项目': {
            sourceDir = path.resolve(__dirname, templatesPath + 'kz-react-project');
            break;
        }
        case 'react模块': {
            //todo
            break;
        }
        case 'vue模块': {
            //todo
            break;
        }
        case '纯webpack模板': {
            sourceDir = path.resolve(__dirname, templatesPath + 'webpack');
            break;
        }
        case 'node中间层模板': {
            sourceDir = path.resolve(__dirname, templatesPath + 'midway');
            break;
        }
        case 'node-server': {
            sourceDir = path.resove(__dirname, templatesPath + 'node-server');
            break;
        }
        default:
            sourceDir = path.resolve(__dirname, templatesPath + 'webpack');
            break;
    }

    generate(name, sourceDir);
}

function isDef(arg) {
    return arg !== undefined && arg !== null;
}

function isUndef(arg) {
    return arg === undefined || arg === null;
}

function checkName(name) {
    if (isUndef(name)) {
        console.log('请输入项目名称！');
        process.exit(1);
    }
}

function selectTemplate(name) {
    inquirer.prompt([{
        type: 'list',
        message: '创建什么项目',
        choices: [
            'react项目',
            'vue项目',
            '快站平台react项目',
            'react模块',
            'vue模块',
            '纯webpack模板',
            '自定义模板',
            'node中间层模板',
            'node-server',
        ],
        name: 'selected',
    }])
    .then((answer) => {
        console.log(`starting building ${answer.selected}...`);
        if (answer.selected === '自定义模板') {
            inquirer.prompt([{
                type: 'input',
                message: '自定义模板git仓库',
                name: 'gitPath',
            }])
            .then((input) => {
                if (isUndef(input.gitPath) || input.gitPath === '') {
                    console.log('请输入git仓库地址！');
                    process.exit(1);
                }
                start(name, answer.selected, input.gitPath)
            });

        } else {
            start(name, answer.selected);
        }
    })
    .catch((err) => {
        console.log('error: ', err);
        process.exit(1);
    })
}

function genPackageJSON(name, appName, sourceDir) {
    let filePath = sourceDir + '/package.json';
    let str = fs.readFileSync(filePath, 'utf-8');
    str = str.replace(/{{appName}}/g, appName);
    fs.writeFileSync(`./${name}/package.json`, str);
}


function moveBasicFiles(name, sourceDir) {
    let files = fs.readdirSync(sourceDir);
    // let basicFilesArr = ['src', 'build', 'config', '.eslintrc.js', '.stylelintrc.js'];

    files.forEach((item) => {
        if (item === 'package.json') return;
        fs.copySync(sourceDir + '/' + item, `./${name}/${item}`);
    })
}


function installDependences(name) {
    process.chdir(name)
    spawn('kz', ['init'], { stdio: 'inherit' });
}

function cloneAndGenerate(name, gitUrl) {
    let tempDir = path.resolve(__dirname, './tmp');
    let spinner = ora('从git仓库下载模板文件...');

    if (exists(tempDir)) {
        rm(tempDir);
    }

    spinner.start();
    download(gitUrl, tempDir, { clone: 'clone' }, (err) => {
        if (err) {
            console.log('download git repo error: ', err);
        }
        spinner.stop();
        generate(name, tempDir);
    })
}

function generate(name, sourceDir) {
    const root = path.resolve(name);
    const appName = path.basename(root);

    genPackageJSON(name, appName, sourceDir);
    moveBasicFiles(name, sourceDir);
    installDependences(name);
}

module.exports = createApp;
