#!/usr/bin/env node
/******************************************************************************
 *
 *
 *       快站前端项目脚手架
 *       author： 闫昊
 *       time:2017/07/15
 *
 ******************************************************************************/

const path = require('path');
const execSync = require('child_process').execSync;
const fs = require('fs-extra');
const download = require('download-git-repo');
const ora = require('ora');
const spawn = require('cross-spawn');
const program = require('commander');
const inquirer = require('inquirer');
const rm = require('rimraf').sync;
const exists = require('fs').existsSync;
const packageJson = require('./package.json');
const createApp = require('./lib/createApp.js');
const initProject = require('./lib/initProject.js');
const build = require('./lib/buildApp.js');
const publish = require('./lib/publishApp.js');
const addKZPackage = require('./lib/addKZPackage.js');

const outputVersion = () => {
    console.log(packageJson.version);
};

program
    .description('快站前端工具')
    .option('-v, --version', '输出版本号', outputVersion);

program
    .command('create [project-name]')
    .description('创建新项目')
    .action((projectName) => {
        if (!projectName) {
            inquirer.prompt({
                type: 'input',
                message: '请输入项目名称',
                name: 'projectName',
            }).then((input) => {
                if (!input.projectName) {
                    program.outputHelp();
                    return;
                } else {
                    createApp(input.projectName);
                }
            })
        } else {
            createApp(projectName);
        }
    });

program
    .command('init')
    .option('-S, --save', '保存更新版本')
    .description('初始化项目')
    .action((command) => {
        initProject(command);
    });

program
    .command('add <packageName>')
    .description('添加快站库')
    .action((packageName) => {
        addKZPackage(packageName);
    });

program
    .command('dev')
    .description('启动开发环境')
    .action(() => {
        spawn('npm', ['run', 'dev'], { stdio: 'inherit' });
    });

program
    .command('build')
    .description('执行构建打包')
    .action(() => {
        console.log('build');
        build();
    });

program
    .command('publish <env>')
    .description('打包发布')
    .action((env) => {
        console.log('publish', env)
        publish();
    });

program.parse(process.argv);


