# 快站前端数据源定义

## 定义接口组

接口组主要用于接口进行分组，一个接口组可以定义该分组下的请求、响应进行统一的预处理。

```js
import ds from 'kz-ds';

// 定义接口组v1
ds.registerGroup('v1', {
    urlPrefix: conf.get('url_app_v1'),
    requestProcessor: (req) => {
        if (req.body) {
            if (!req.headers) {
                req.headers = {};
            }
            req.headers['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8';
            req.body = encodeQueryString(req.body);
        }
        return req;
    },
});
```

其中接口组名不能包括目录符号('/')，可以使用英文、数组和连字符定义接口组名。

注册接口组时，可以自定义的参数如下：

* urlPrefix 接口URL前缀
* requestProcessor 定义请求预处理
* responseProcessor 定义响应预处理

## 定义接口

接口必须定义在某个接口分组下，否则将处于一个默认的全局分组下。

使用如下调用定义一个接口：

```js
// 登录接口
ds.register('v1/passport.login', {
    type: 'post',
    url: '/passport/ajax-login',
});
```

ds.register 签名为ds.register(apiName, apiSettings)

其中apiSettings 对象可定义的参数如下：

* type 请求方法名，大小写均可
* url 接口URL
* params Object类型，定义URL path参数
* headers Object类型，定义请求头

接口名格式如下：
```
<接口组名>/<业务分组名>.<业务模块名>.<接口操作>
```

其中：

* <业务分组名>、<业务模块名>、<接口操作>可使用小写字母、数组、连字符命名，使用英文句号('.')隔开。
* <业务模块名> 统一使用单数
* <接口操作> 统一使用动词词组，比如 get-info, update-settings 等等。


## 使用接口

使用接口示例如下：

```js
ds.resolve('v1/passport.login', {
    body: { username, password },
})
.then((res) => {
    //...
})
.catch((e) => {
    console.log(e);
});
```

## 已命名数据源

### 接口组 v1
对应于平台kuaizhan_cl 项目中的ajax接口

### 接口组 v2
对应于平台kz-theme 项目中的ajax接口

