import React from 'react';
import PropTypes from 'prop-types';
import {
    BrowserRouter as Router,
    Route,
    Switch,
    Redirect,
} from 'react-router-dom';
import { ContextProvider } from 'kz-frame';
import { passportStatus } from 'kz-frame/passport/actions';
import { connect } from 'react-redux';
import MainLayout from './components/main-layout';
import PageDemo from './demo';
import { typeDs, typeLocation } from './utils/types';
import { pageUrl, isOutsideLocation } from './utils/url';
import { decodeQuerySting } from './utils/qs';
import './static/less/roboto.less';

const kzstoreListPages = [
    {
        link: pageUrl('/demo/'),
        page: PageDemo,
    },
];

const NoMatchFound = ({ location }) => {
    if (isOutsideLocation(location)) {
        window.location = `${location.pathname}${location.search}${location.hash}`;
        return;
    }
    return (
        <div>
            <h3>404 Not Found: <code>{location.pathname}</code></h3>
        </div>
    );
};

NoMatchFound.propTypes = {
    location: typeLocation,
};

NoMatchFound.defaultProps = {
    location: null,
};

const query = decodeQuerySting(window.location.search);
const siteId = parseInt(query.site_id, 10);
const redirect = query.redirect;
const weixinAppid = parseInt(query.weixin_id, 10);

class App extends React.Component {
    componentDidMount() {
        const { dispatch, ds } = this.props;
        // 获取登录状态
        dispatch(passportStatus(ds));
    }

    render() {
        const { ds, offline } = this.props;
        const children = [];

        if (offline) {
             // 如果处于离线状态,跳到登录页
            window.location.assign(
                `http://${window.location.host}/passport/login?refer=${encodeURI(window.location.href)}`);
            return null;
        }

        kzstoreListPages.forEach((page) => {
            children.push(
                <Route
                    key={children.length}
                    path={page.link}
                    component={MainLayout(page.page)}
                />,
            );
        });

        if (redirect) {
            children.push(<Redirect to={pageUrl(redirect)} />);
        }

        return (
            <ContextProvider ds={ds} siteId={siteId} weixinAppid={weixinAppid}>
                <Router>
                    <Switch>
                        {children}
                        <Route component={NoMatchFound} />
                    </Switch>
                </Router>
            </ContextProvider>
        );
    }
}

App.propTypes = {
    ds: typeDs,
    offline: PropTypes.bool,
};

App.defaultProps = {
    ds: null,
    offline: true,
};

export default connect(
    state => ({
        offline: (state.passport.status === 'offline'),
    }),
)(App);
