import {
    showAlert,
} from '../alert/actions';

export const displayMyPic = picList => ({
    picList,
    type: 'picSelector.displayMyPic',
});

export const displayGallery = galleryList => ({
    galleryList,
    type: 'picSelector.displayGallery',
});

export const displaySelect = select => ({
    select,
    type: 'picSelector.displaySelect',
});

export const displayTag = tag => ({
    tag,
    type: 'picSelector.displayTag',
});

export const displaySearch = query => ({
    query,
    type: 'picSelector.displaySearch',
});

export const picFetchNext = page => ({
    page,
    type: 'picSelector.picFetchNext',
});

export const galleryFetchNext = page => ({
    page,
    type: 'picSelector.galleryFetchNext',
});

export const selectPic = pic => ({
    pic,
    type: 'picSelector.selectPic',
});

export const displayUpload = uploadTotal => ({
    uploadTotal,
    type: 'picSelector.displayUpload',
});

export const dismissUpload = () => ({
    type: 'picSelector.dismissUpload',
});

export const uploadIndex = index => ({
    index,
    type: 'picSelector.uploadIndex',
});

export const galleryMore = more => ({
    type: 'picSelector.galleryMore',
    galleryMore: more,
});

export const picMore = more => ({
    type: 'picSelector.picMore',
    picMore: more,
});

export const displayOptions = options => ({
    type: 'picSelector.displayOptions',
    options,
});

export const galleryFetch = (ds, opts) => (dispatch, getState) => {
    const params = opts;
    if (params.cate === '全部') {
        params.cate = 0;
    }

    ds.resolve('v1/pic', {
        qs: params,
    }).then((res) => {
        const data = res.body;
        if (data.ret === 0) {
            if (data.data.list.length > 0) {
                const state = getState();
                const list = state.picSelector.galleryList.concat(data.data.list);
                dispatch(displayGallery(list, params.page));
            } else {
                dispatch(galleryMore(false));
            }
        }
    });
};

export const myPicFetch = (ds, opts) => (dispatch, getState) => {
    const {
        site_id,
        curr_page,
        per_page,
        criteria,
        tag_name,
    } = opts;

    ds.resolve('v1/list-pic-by-tag', {
        qs: {
            site_id,
            curr_page,
            per_page,
            criteria,
            tag_name,
        },
    }).then((res) => {
        const data = res.body;
        if (data.ret === 0) {
            if (data.data.length > 0) {
                const state = getState();
                const list = state.picSelector.picList.concat(data.data);
                dispatch(displayMyPic(list, curr_page));
            } else {
                dispatch(picMore(false));
            }
        }
    });
};

export const optionsFetch = (ds, siteId) => (dispatch) => {
    ds.resolve('v1/list-tag', {
        qs: {
            site_id: siteId,
        },
    }).then((res) => {
        if (res.body.ret === 0) {
            const data = res.body.data;
            const options = [];
            for (let i = 0; i < data.length; i += 1) {
                options.push({
                    value: data[i].name,
                    text: `${data[i].name}（${data[i].count}）`,
                });
            }
            dispatch(displayOptions(options));
            dispatch(myPicFetch(ds, {
                site_id: siteId,
                curr_page: 1,
                per_page: 15,
                criteria: 1,
                tag_name: options[0].value,
            }));
        }
    });
};

export const selectChange = (ds, siteId, select) => (dispatch, getState) => {
    const state = getState();
    if (select === state.picSelector.curSelect) {
        return;
    }
    dispatch(displaySelect(select));
    dispatch(picMore(true));
    dispatch(myPicFetch(ds, {
        site_id: siteId,
        curr_page: 1,
        per_page: 15,
        criteria: 1,
        tag_name: select,
    }));
};

export const tagChange = (ds, siteId, tag) => (dispatch, getState) => {
    const state = getState();
    if (tag === state.picSelector.curTag) {
        return;
    }
    dispatch(displayTag(tag));
    dispatch(displaySearch(''));
    dispatch(galleryMore(true));
    dispatch(galleryFetch(ds, {
        page: 1,
        per_page: 15,
        cate: tag,
        query: '',
        site_id: siteId,
    }));
};

export const searchGallery = (ds, siteId, query) => (dispatch, getState) => {
    const state = getState();
    if (query === state.picSelector.query) {
        return;
    }
    dispatch(displaySearch(query));
    dispatch(galleryFetch(ds, {
        page: 1,
        per_page: 15,
        cate: state.picSelector.curTag,
        query,
        site_id: siteId,
    }));
};

export const PicFetchNext = (ds, siteId) => (dispatch, getState) => {
    const state = getState();
    dispatch(myPicFetch(ds, {
        site_id: siteId,
        curr_page: state.picSelector.picPage + 1,
        per_page: 15,
        criteria: 1,
        tag_name: state.picSelector.curSelect,
    }));
    dispatch(picFetchNext(state.picSelector.picPage + 1));
};

export const GalleryFetchNext = (ds, siteId) => (dispatch, getState) => {
    const state = getState();
    dispatch(galleryFetch(ds, {
        page: state.picSelector.galleryPage + 1,
        per_page: 15,
        cate: state.picSelector.curTag,
        query: state.picSelector.query,
        site_id: siteId,
    }));
    dispatch(galleryFetchNext(state.picSelector.galleryPage + 1));
};

export const refreshPic = (ds, siteId) => (dispatch, getState) => {
    const state = getState();
    const select = state.picSelector.curSelect;
    dispatch(displaySelect(select));
    dispatch(picMore(true));
    dispatch(myPicFetch(ds, {
        site_id: siteId,
        curr_page: 1,
        per_page: 15,
        criteria: 1,
        tag_name: select,
    }));
};

export const confirmPicSelect = () => (dispatch, getState) => {
    const state = getState();
    if (state.picSelector.selected.length === 0) {
        dispatch(showAlert('未选择图片'));
    }
};
