import React from 'react';
import PropTypes from 'prop-types';
import {
    KZUIComponent,
    Button,
    Dialog,
} from 'kui2';
import { connect } from 'react-redux';
import './style.less';
import { hidePicViewDialog, getPicSize } from './actions';

class PicViewDialog extends KZUIComponent {
    constructor(props) {
        super(props);
        this.autoBind('handleCancel', 'handleConfirm');
    }

    initStateFromProps(props) {
        if (props.pic.url !== this.props.pic.url) {
            this.props.dispatch(getPicSize(props));
        }
    }

    handleCancel() {
        this.props.dispatch(hidePicViewDialog);
        if (this.props.onCancel) {
            this.props.onCancel();
        }
    }

    handleConfirm() {
        this.props.dispatch(hidePicViewDialog);
        if (this.props.onConfirm) {
            this.props.onConfirm({
                pic: this.props.pic,
                picIndex: this.props.picIndex,
            });
        }
    }

    render() {
        const { pic, hide, width, height } = this.props;
        return (
            <Dialog modal className="ui-pop-lite-selector" hide={hide}>
                <div className="item-view">
                    <img src={pic.url} alt={pic.name} />
                </div>
                <p className="name">{pic.name}</p>
                <p className="size">{`${width} x ${height}`}</p>
                <div className="btn-con">
                    <Button
                        className="select-confirm"
                        type="confirm"
                        onClick={this.handleConfirm}
                    >
                    选择
                    </Button>
                    <Button className="select-cancel" onClick={this.handleCancel}>
                    取消
                    </Button>
                </div>
            </Dialog>
        );
    }
}

PicViewDialog.propTypes = {
    pic: PropTypes.shape({
        name: PropTypes.string,
        url: PropTypes.string,
    }),
    picIndex: PropTypes.number,
    width: PropTypes.number,
    height: PropTypes.number,
    onConfirm: PropTypes.func,
    onCancel: PropTypes.func,
};

PicViewDialog.defaultProps = {
    pic: {},
    picIndex: -1,
    width: 0,
    height: 0,
    onConfirm: null,
    onCancel: null,
};

export default connect(
    state => state.picSelector.picViewDialog,
)(PicViewDialog);
