import React from 'react';
import PropTypes from 'prop-types';
import { KZUIComponent } from 'kui2';
import { connect } from 'react-redux';
import Picture from '../picture';
import PicViewDialog from '../pic-view-dialog/index';
import { showPicViewDialog } from '../pic-view-dialog/actions';
import { picListType } from '../../types';

class PicLib extends KZUIComponent {
    constructor(props) {
        super(props);
        this.state = {
            selected: {},
        };
        this.autoBind('handleScroll', 'handleClickPicture', 'handlePicConfirm', 'handlePicView');
    }

    handleScroll() {
        if (this.props.onScroll) {
            const clientHeight = this.bodyBox.clientHeight;
            const scrollTop = this.bodyBox.scrollTop;
            const scrollHeight = this.bodyBox.scrollHeight;
            if (scrollHeight - clientHeight - scrollTop < 50) {
                this.props.onScroll();
            }
        }
    }

    handleClickPicture(pic) {
        const data = {
            url: pic.url,
            name: pic.name,
        };
        this.setState({
            selected: {
                [pic.index]: data,
            },
        });
        if (this.props.onClick) {
            this.props.onClick(data);
        }
    }

    handlePicView({ pic, picIndex }) {
        this.props.dispatch(showPicViewDialog(pic, picIndex));
    }

    handlePicConfirm({ pic, picIndex }) {
        const data = {
            url: pic.url,
            name: pic.name,
        };
        this.setState({
            selected: {
                [picIndex]: data,
            },
        });
        if (this.props.onClick) {
            this.props.onClick(data);
        }
    }

    render() {
        return (
            <div
                className="pic-view"
                onScroll={this.handleScroll}
                ref={this.storeRef('bodyBox')}
            >
                <ul className="type-ul">
                    {this.props.list.map((pic, key) => (
                        <Picture
                            key={`${key}-${Object.prototype.hasOwnProperty.call(this.state.selected, key)}`}
                            index={key}
                            active={Object.prototype.hasOwnProperty.call(this.state.selected, key)}
                            pic={pic}
                            picIndex={key}
                            onClick={this.handleClickPicture}
                            onPicViewClick={this.handlePicView}
                        />
                    ))}
                </ul>
                <PicViewDialog onConfirm={this.handlePicConfirm} />
            </div>
        );
    }
}

PicLib.propTypes = {
    list: picListType,
    onScroll: PropTypes.func,
    onClick: PropTypes.func,
};

PicLib.defaultProps = {
    list: [],
    onScroll: null,
    onClick: null,
};

export default connect()(PicLib);
