import React from 'react';
import PropTypes from 'prop-types';
import {
    KZUIComponent,
} from 'kui2';
import { picType } from '../../types';
import './style.less';

class Picture extends KZUIComponent {
    constructor(props) {
        super(props);
        if (this.props.active) {
            this.state = {
                selected: true,
            };
        } else {
            this.state = {
                selected: false,
            };
        }
        this.autoBind('handleConfirm', 'handleViewClick');
    }

    handleClick() {
        this.setState({
            selected: !this.state.selected,
        });
        if (this.props.onClick) {
            this.props.onClick({
                ...this.props.pic,
                index: this.props.index,
            });
        }
    }

    handleConfirm() {
        this.setState({
            ...this.state,
            selected: true,
        });
        if (this.props.onClick) {
            this.props.onClick({
                ...this.props.pic,
                index: this.props.index,
            });
        }
    }

    handleViewClick(e) {
        e.stopPropagation();
        if (this.props.onPicViewClick) {
            this.props.onPicViewClick(this.props);
        }
    }

    render() {
        const className = this.classname('type-li', {
            cur: this.state.selected,
        }, true);

        return (
            <li role="presentation" className={className}>
                <div className="option" role="presentation" onClick={this.handleClick}>
                    <div className="outter_box">
                        <div className="inner_box">
                            <img
                                className="img"
                                src={this.props.pic.url}
                                alt={this.props.pic.name}
                            />
                            <p
                                id="pic-pop"
                                role="presentation"
                                className="view"
                                onClick={this.handleViewClick}
                            >
                                查看
                            </p>
                        </div>
                        <p title={this.props.pic.name}>{this.props.pic.name}</p>
                    </div>
                    <i className="ico" />
                </div>
            </li>
        );
    }
}

Picture.propTypes = {
    active: PropTypes.bool,
    onClick: PropTypes.func,
    onPicViewClick: PropTypes.func,
    pic: picType,
    index: PropTypes.number,
};

Picture.defaultProps = {
    active: false,
    onClick: null,
    onPicViewClick: null,
    pic: {},
    index: 0,
};

export default Picture;
