import ds from 'kz-ds';
import conf from '../conf/index';
import { encodeQueryString } from '../utils/qs';

// 定义接口组v1
ds.registerGroup('v1', {
    urlPrefix: conf.get('url_app_v1'),
    requestProcessor: (req) => {
        if (req.body) {
            if (!req.headers) {
                req.headers = {};
            }
            if (!(req.body instanceof FormData)) {
                req.headers['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8';
                req.body = encodeQueryString(req.body);
            }
        }
        return req;
    },
    responseProcessor: (res) => {
        if (res.body && typeof res.body === 'string') {
            try {
                res.body = JSON.parse(res.body);
            } catch (e) {
                throw new Error('网络请求失败');
            }
        }
        return res;
    },
});

// 注册v2接口组
ds.registerGroup('v2', {
    urlPrefix: conf.get('url_app_v2'),
    requestProcessor: (req) => {
        if (req.body) {
            if (!req.headers) {
                req.headers = {};
            }
            if (!req.headers['Content-Type'] && !(req.body instanceof FormData)) {
                req.headers['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8';
                req.body = encodeQueryString(req.body);
            } else if (req.headers['Content-Type'] === 'application/json') {
                req.body = JSON.stringify(req.body);
            }
        }
        return req;
    },
});

export default ds;
