/* eslint-disable no-underscore-dangle */
import React from 'react';
import { Pager, KZUIComponent, prompt } from 'kui2';
import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import SiteList from './components/site-list';
import KzstoreConfirm from './components/confirm';
import PaymentMode from './components/payment-mode';
import {
    fetchSiteList,
    checkSitePlugin,
    setOpenMessage,
    openPlugin,
    getPluginBackendPage,
} from './actions';
import { decodeQuerySting } from '../utils/qs';
import { PLUGIN_STATUS,
         PLUGIN_TYPES,
} from './settings';
import './style.less';

const queryStr = window.location.search;
const pluginId = decodeQuerySting(queryStr).plugin_id;

class KzstorePage extends KZUIComponent {

    constructor(props) {
        super(props);
        this.autoBind(
            'onPageChange',
            'selectSite',
            'handleConfirmClick',
            'handleCancelClick',
            'handlePayWayClick',
            'isPluginFree',
        );
        this.state = {
            confirmState: false,
            confirmType: '',
            siteName: '',
            siteId: '',
            balance: '0.00', // 某个站点的余额，checkSitePlugin 后获取, 是 string
            pluginBackendUrl: '', // 插件的后台管理页面
        };
    }

    componentWillReceiveProps(nextProps) {
        const { totalPage } = nextProps;
        if (this.props.totalPage !== totalPage) {
            if (totalPage === 0) {
                this.showConfirm('siteNotFound');
            } else {
                this.hideConfirm();
            }
        }
    }

    componentDidMount() {
        const { ds } = this.context;
        this.props.dispatch(fetchSiteList(ds, {
            pluginId,
        }));
        getPluginBackendPage(ds, {
            pluginId,
        }).then((ret) => {
            const link = ret.body.data;
            this.setState({
                pluginBackendUrl: link,
            });
        });
    }

    onPageChange(curPage) {
        const { ds } = this.context;
        this.props.dispatch(fetchSiteList(ds, {
            curPage,
        }));
    }

    selectSite(siteId, siteName) {
        const { ds } = this.context;
        const that = this;
        checkSitePlugin(ds, {
            siteId,
            pluginId,
        }).then((res) => {
            if (res.ret === PLUGIN_STATUS.SUCEESS) {
                let balance = res.data && res.data[siteId].balance;
                balance = balance !== false ? balance : '-1'; // 值为'-1'证明后台没有返回该信息
                that.setState({
                    confirmState: true,
                    confirmType: 'payway',
                    siteName,
                    siteId,
                    balance,
                });
            } else if (res.ret === PLUGIN_STATUS.FAILURE) {
                that.setState({
                    confirmState: true,
                    confirmType: 'alreadyOpened',
                    siteName,
                    siteId,
                });
            }
        });
    }

    showConfirm(type) {
        this.setState({
            confirmType: type,
            confirmState: true,
        });
    }

    hideConfirm() {
        this.setState({
            confirmType: '',
            confirmState: false,
        });
    }

    handleConfirmClick(type) {
        const { ds } = this.context;
        const { openMessage, plugin, siteList } = this.props;
        const { siteId } = this.state;

        const sites = siteList.filter(site => site.id === siteId);
        const pageId = (sites.length > 0 && sites[0].index_page_id) ? sites[0].index_page_id : '';

        if (type === 'open') {
            openPlugin(ds, {
                siteId,
                pluginId: plugin._id,
                type: openMessage.unitType,
                quantity: openMessage.quantity,
            }).then((res) => {
                const msg = res.body.msg;
                if (res.body.ret === 0) {
                    switch (plugin.app_type) {
                    case PLUGIN_TYPES.PAGE:
                        window.location.href = pageId !== '' ?
                            `/kzweb/v1/page-edit?page_id=${pageId}&isPurchased=true` :
                                '/v3/site';
                        break;
                    case PLUGIN_TYPES.PLUGIN:
                        if (this.state.pluginBackendUrl === '/') {
                            window.location.href = pageId !== '' ?
                                `/kzweb/v1/page-edit?page_id=${pageId}` :
                                '/v3/site';
                        } else {
                            const backendUrl = this.state.pluginBackendUrl.replace('{{site_id}}', siteId);
                            window.location.href = backendUrl;
                        }
                        break;
                    case PLUGIN_TYPES.POSTER:
                        window.location.href = `/pp/page/manage/create2?site_id=${siteId}&isPurchased=true`;
                        break;
                    default:
                        window.location.href = '/v3/site';
                    }
                } else {
                    prompt.alert(msg);
                }
            }).catch(() => {
                prompt.alert('应用开启失败');
            });
        } else if (type === 'lackOfMoneny') {
            window.open('/kzcoin/index');
        } else if (type === 'siteNotFound') {
            window.location.href = '/template/list';
        }
        this.hideConfirm();
    }
    handleCancelClick() {
        this.hideConfirm();
    }
    handlePayWayClick(openMessage) {
        const { dispatch } = this.props;
        const { siteName } = this.state;
        dispatch(setOpenMessage({
            ...openMessage,
            siteName,
        }));
        this.showConfirm('open');
    }

    render() {
        const {
            siteList,
            curPage,
            totalPage,
            plugin,
        } = this.props;

        return (
            <div className="kzstore-list-page">
                <span className="tip">
                    您正在开启应用
                    <a
                        href={`/plugin/intro?plugin_id=${plugin._id}`}
                        target="blank"
                        className="plugin"
                    >
                        {plugin.title}
                    </a>
                    ，请选择需要添加该应用的站点：
                </span>
                <SiteList siteList={siteList} selectSite={this.selectSite} />
                {
                    totalPage > 0 ?
                        <Pager
                            className="kzstore-pager"
                            curPage={curPage}
                            totalPage={totalPage}
                            onPageChange={this.onPageChange}
                        /> :
                    null
                }
                { this.state.confirmState &&
                this.state.confirmType !== '' &&
                this.state.confirmType !== 'payway' ?
                    <KzstoreConfirm
                        type={this.state.confirmType}
                        handleCancelClick={this.handleCancelClick}
                        handleConfirmClick={this.handleConfirmClick}
                    /> :
                    null
                }
                { this.state.confirmState &&
                    this.state.confirmType === 'payway' ?
                        <PaymentMode
                            balance={this.state.balance}
                            onConfirm={this.handlePayWayClick}
                            onCancel={this.handleCancelClick}
                        /> :
                    null
                }
            </div>
        );
    }
}

KzstorePage.contextTypes = {
    ds: PropTypes.object,
};

KzstorePage.propTypes = {
    curPage: PropTypes.number.isRequired,
    totalPage: PropTypes.number.isRequired,
    perPage: PropTypes.number.isRequired,
};

export default connect(
    state => ({
        ...state.kzstore.page,
        openMessage: state.kzstore.openMessage,
        plugin: state.kzstore.plugin,
        siteList: state.kzstore.list,
    }),
)(KzstorePage);
