const keyPrefix = 'kz';
const getKey = key => (`${keyPrefix}-${key}`);

const engineAPIs = engine => ({
    get(key, returnRaw = false) {
        const str = engine.getItem(getKey(key));
        if (str) {
            const meta = JSON.parse(str);
            if (returnRaw) {
                return meta;
            }
            // check timeout
            if (meta.options.timeout) {
                const now = Date.now();
                if (now - meta.updateTime > (meta.options.timeout * 1000)) {
                    return null;
                }
            }
            return meta.value;
        }
        return null;
    },

    set(key, value, options = {}) {
        const prev = this.get(key, true);
        let meta;
        if (prev) {
            meta = {
                ...prev,
                options,
                updateTime: Date.now(),
            };
        } else {
            meta = {
                value,
                options,
                createTime: Date.now(),
                updateTime: Date.now(),
            };
        }
        engine.setItem(getKey(key), JSON.stringify(meta));
    },
});

export const sessionStorage = engineAPIs(window.sessionStorage);

export const localStorage = engineAPIs(window.localStorage);

export default localStorage;
