const shell = require('shelljs');
const path = require('path');
const webpack = require('webpack');
const AddAssetHtmlPlugin = require('add-asset-html-webpack-plugin');
const jsRules = require('./webpack/rules/js');
const lessRules = require('./webpack/rules/less');
const assertsRules = require('./webpack/rules/asserts');
const pluginRules = require('./webpack/plugins');
const manifestJSON = require('./dll/lib-manifest.json');
const HappyPack = require('happypack');
const happyThreadPool = HappyPack.ThreadPool({ size: 2 });
// const lessLoader = require('./webpack/less-loader');
const eslintFriendlyFormatter = require('eslint-friendly-formatter');
// const pkg = require('./package.json');

const env = process.env;
const destPath = path.join(__dirname, 'dist');

if (!env.NODE_ENV) {
    env.NODE_ENV = 'dev';
}
// remove prev build
shell.rm('-rf', destPath);

// copy env conf
shell.cp(`./conf/${env.NODE_ENV}/conf.json`, './src/conf/');
// load build conf
const buildConf = require(`./deploy/${env.NODE_ENV}/conf.json`);
const { pathPrefix, publicPath } = buildConf;
const context = {
    env,
    pathPrefix,
    rootDir: __dirname,
};

const resolvePath = relativePath => (path.resolve(__dirname, relativePath));

module.exports = {
    entry: {
        main: resolvePath('src/index.js'),
    },

    output: {
        publicPath,
        path: destPath,
        filename: `[name].[hash:8].js`,
    },

    resolve: {
        extensions: [".js", ".jsx"],
    },

    externals: {
    },

    module: {
        rules: [
            ...jsRules(context),
            ...lessRules(context),
            ...assertsRules(context),
        ],
    },

    plugins: [
        ...pluginRules(context),
        new webpack.DllReferencePlugin({
            context: __dirname,
            manifest: manifestJSON,
        }),
        new HappyPack({
            id: 'js',
            threadPool: happyThreadPool,
            loaders: [
                'babel-loader',
            ],
        }),
        new HappyPack({
            id: 'less',
            threadPool: happyThreadPool,
            loaders: [
                'css-loader',
                'postcss-loader',
                'less-loader',
            ],
        }),
        new AddAssetHtmlPlugin({
            filepath: resolvePath('dll/lib*.dll.js'),
            includeSourcemap: false,
        }),
    ],

    devServer: {
        port: 80,
        host: "www.dev.com",
        proxy: {
            '/v1/': {
                target: 'http://10.11.172.135',
                pathRewrite: { '^/v1' : '' },
                secure: false,
                headers: { host: 'www.dev.com' },
            },
            '/api/v2/': {
                target: 'http://10.11.172.135',
                pathRewrite: { '^/api': '' },
                secure: false,
                headers: { host: 'www.dev.com'},
            },
        },
        compress: true,
        contentBase: path.join(__dirname, 'dist'),
        historyApiFallback: true,
        stats: {
            children: false,
        }
    },
    stats: {
        children: false,
    },
};
