const shell = require('shelljs');
const path = require('path');
const webpack = require('webpack');
const jsRules = require('./webpack/rules/js');
const lessRules = require('./webpack/rules/less');
const assertsRules = require('./webpack/rules/asserts');
const pluginRules = require('./webpack/plugins');
// const pkg = require('./package.json');

const env = process.env || 'dev';
const destPath = path.join(__dirname, 'dll');

shell.rm('-rf', destPath);

const resolvePath = relativePath => (path.resolve(__dirname, relativePath));

module.exports = {
    entry: {
        lib: [
            'react',
            'redux',
            'redux-thunk',
            'react-dom',
            'react-redux',
            'react-router',
            'react-router-dom',
            'prop-types',
            'moment',
            'kz-jquery',
            'qrcode',
        ],
        // ueditor: [
            // 'kz-ueditor',
        // ],
    },

    output: {
        path: destPath,
        filename: `[name]_[hash:8].dll.js`,
        library: '[name]',
    },

    resolve: {
        extensions: [".js", ".jsx"],
    },

    module: {
        rules: [
            {
                test: /\.css$/,
                use: [
                    'style-loader',
                    'css-loader',
                ],
            },
            {
                test: /\.(png|jpg|jpeg|gif|webp)$/,
                loader: 'file-loader?name=images/[name].[hash:8].[ext]',
            },
        ],
    },

    // plugins: pluginRules(context),
    plugins: [
        new webpack.DefinePlugin({
            'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV || 'production'),
        }),
        new webpack.DllPlugin({
            context: __dirname,
            path: resolvePath('dll/[name]-manifest.json'),
            name: '[name]'
        }),
        new webpack.optimize.UglifyJsPlugin({
            warnings: false,
            sourceMap: true,
        }),
    ],
    devtool: 'cheap-source-map',
};
