const webpack = require('webpack');
const ExtractTextPlugin = require("extract-text-webpack-plugin");
const HtmlWebpackPlugin = require('html-webpack-plugin');
const UglifyJSPlugin = require('uglifyjs-webpack-plugin');
const StyleLintPlugin = require('stylelint-webpack-plugin');
const StyleLintFormatter = require('stylelint-formatter-pretty');

module.exports = (context) => {
    const plugins = [
        new StyleLintPlugin({
            syntax: 'less',
            files: 'src/**/*.l?(e|c)ss',
            formatter: StyleLintFormatter,
        }),
        new ExtractTextPlugin({
            filename: 'css/[name].[contenthash:8].css',
        }),
        new HtmlWebpackPlugin({
            filename: 'index.html',
            template: 'src/index.html',
            hash: false,
            inject: true,
        }),
        // new webpack.optimize.CommonsChunkPlugin({
            // name: ['vendors', 'manifest'],
            // minChunks: Infinity,
        // }),
    ];

    if (context.env.NODE_ENV === 'production') {
        plugins.unshift(new UglifyJSPlugin({
            compress: true,
        }));
    }

    return plugins;
};
