const path = require('path');
const resolve = dir => path.resolve(__dirname, '..', dir);
const baseConfig = require('../config');
const basePlugins = require('./webpackConfig/basePlugins.js');
const baseRules = require('./webpackConfig/baseRules.js');
const env = process.env;

env.NODE_ENV = env.NODE_ENV || 'dev';

const context = {
    env,
    pathPrefix: '/',
    rootDir: resolve('./'),
}

module.exports = {
    entry: {
        app: resolve('src/index.js'),
    },

    output: {
        publicPath: baseConfig.prod.publicPath,
        path: resolve(baseConfig.prod.distPath),
        filename: '[name].[chunkhash:8].js',
    },

    resolve: {
        extensions: ['.js', '.jsx', 'json'],
    },

    module: {
        rules: [
            ...baseRules(context),
        ],

    },

    plugins: [
        ...basePlugins(context),
    ],

    devServer: {
        port: 8888,
        host: 'www.dev.com',
    },
}
